from django.contrib import admin
from .models import AddressPlugin, MenuNode, Page, Plugin, TextPlugin


class PageAdmin(admin.ModelAdmin):
    list_display = ('id', 'name', 'created', 'last_updated')
    search_fields = ('id', 'name')
admin.site.register(Page, PageAdmin)


class MenuNodeAdmin(admin.ModelAdmin):
    list_display = ('id', 'title', 'page', 'enabled')
    search_fields = ('id', 'title', 'page', 'enabled')
admin.site.register(MenuNode, MenuNodeAdmin)


class PluginAdmin(admin.ModelAdmin):
    list_display = ('id', 'position', 'content_object')
    search_fields = ('id', 'position', 'content_object')
admin.site.register(Plugin, PluginAdmin)


class TextPluginAdmin(admin.ModelAdmin):
    list_display = ('id', 'content')
admin.site.register(TextPlugin, TextPluginAdmin)


class AddressPluginAdmin(admin.ModelAdmin):
    list_display = ('id', 'address')
    search_fields = ('id', 'address')
admin.site.register(AddressPlugin, AddressPluginAdmin)



# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from django.contrib.contenttypes.fields import GenericForeignKey
from django.contrib.contenttypes.models import ContentType
from django.db import models
from django.utils.encoding import python_2_unicode_compatible

from tinymce.models import HTMLField


@python_2_unicode_compatible
class Page(models.Model):
    name = models.CharField(max_length=200, db_index=True)
    content = HTMLField(blank=True, null=True)
    plugins = models.ManyToManyField('Plugin', blank=True)
    created = models.DateTimeField(auto_now_add=True)
    last_updated = models.DateTimeField(auto_now=True)

    def __str__(self):
        return 'Page: ' + str(self.name)


@python_2_unicode_compatible
class MenuNode(models.Model):
    title = models.CharField(max_length=200)
    page = models.ForeignKey(Page, null=True, blank=True)
    children = models.ManyToManyField('self', blank=True)
    enabled = models.BooleanField(default=True)

    def __str__(self):
        return 'MenuNode: ' + str(self.title)


@python_2_unicode_compatible
class Plugin(models.Model):
    position = models.PositiveSmallIntegerField(default=0)
    content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
    object_id = models.PositiveIntegerField()
    content_object = GenericForeignKey()

    def __str__(self):
        return 'Plugin: ' + str(self.content_type) + " " + str(self.object_id)


@python_2_unicode_compatible
class TextPlugin(models.Model):
    content = HTMLField()

    def __str__(self):
        return 'TextPlugin: ' + str(self.content)[:40] + "..."


@python_2_unicode_compatible
class AddressPlugin(models.Model):
    address = models.CharField(max_length=200)

    def __str__(self):
        return 'AddressPlugin: ' + str(self.address)



# -*- coding: utf-8 -*-
from django.core.urlresolvers import reverse_lazy
from django.views.generic import CreateView, DetailView, ListView
from .models import Page


class PageListView(ListView):
    model = Page


class PageCreateView(CreateView):
    model = Page
    fields = ['name', 'content']
    success_url = reverse_lazy('page_list')


class PageDetailView(DetailView):
    model = Page



# -*- coding: utf-8 -*-
from django.conf.urls import url
from django.views.decorators.csrf import csrf_exempt
from . import views


urlpatterns = [
    url(
        regex="^page/$",
        view=views.PageListView.as_view(),
        name='page_list',
    ),
    url(
        regex="^page/create/$",
        view=csrf_exempt(views.PageCreateView.as_view()),
        name='page_create',
    ),
    url(
        regex="^page/(?P<pk>\d+)/$",
        view=views.PageDetailView.as_view(),
        name='page_detail',
    ),
]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-05 03:05
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion
import tinymce.models


class Migration(migrations.Migration):

    dependencies = [
        ('contenttypes', '0002_remove_content_type_name'),
        ('cow', '0002_menunode'),
    ]

    operations = [
        migrations.CreateModel(
            name='AddressPlugin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('address', models.CharField(max_length=200)),
            ],
        ),
        migrations.CreateModel(
            name='Plugin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('position', models.PositiveSmallIntegerField(default=0)),
                ('object_id', models.PositiveIntegerField()),
                ('content_type', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='contenttypes.ContentType')),
            ],
        ),
        migrations.CreateModel(
            name='TextPlugin',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('content', tinymce.models.HTMLField()),
            ],
        ),
        migrations.AlterField(
            model_name='page',
            name='content',
            field=tinymce.models.HTMLField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='page',
            name='plugins',
            field=models.ManyToManyField(blank=True, to='cow.Plugin'),
        ),
    ]



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_cow
------------

Tests for `cow` models module.
"""
from datetime import timedelta
from uuid import uuid4

from django.test import TestCase
from django.utils import timezone

from cow import models


class TestCow(TestCase):
    def test_page_simple(self):
        # stupid test to touch code/models
        page = models.Page.objects.create(name='test1', content='2')
        page.delete()

    def test_menu_node_simple(self):
        # create a page and point at it with model
        page = models.Page.objects.create(name='test1', content='2')
        child = models.MenuNode.objects.create(title='title1', page=page)
        parent = models.MenuNode.objects.create(title='title1')
        parent.children.add(child)
        parent.save()
        self.assertTrue(parent.children.count() > 0)
        parent.delete()
        child.delete()
        page.delete()

    def test_plugins(self):
        # create a text plugin, apply to page, and retrieve
        text_plugin_content = 'yo'
        page = models.Page.objects.create(name='test1')
        text_plugin = models.TextPlugin.objects.create(content=text_plugin_content)
        plugin = models.Plugin.objects.create(content_object=text_plugin)
        page.plugins.add(plugin)
        self.assertTrue(page.plugins.count() > 0)
        self.assertEquals(page.plugins.first().content_object.content, text_plugin_content)
        text_plugin.delete()
        plugin.delete()
        page.delete()




# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-03 03:35
from __future__ import unicode_literals

from django.db import migrations, models
import tinymce.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Page',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(db_index=True, max_length=200)),
                ('content', tinymce.models.HTMLField()),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('last_updated', models.DateTimeField(auto_now=True)),
            ],
        ),
    ]



# -*- coding: utf-8 -*-
# Generated by Django 1.10.6 on 2017-03-04 04:27
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cow', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='MenuNode',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=200)),
                ('enabled', models.BooleanField(default=True)),
                ('children', models.ManyToManyField(blank=True, related_name='_menunode_children_+', to='cow.MenuNode')),
                ('page', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='cow.Page')),
            ],
        ),
    ]
